# 嵌入式 Python

本文件夹包含多个嵌入式版本的 Python.

该嵌入式版本来自于官网 (下载带有 "embed-amd64.zip" 后缀的文件).

# 使用方法

详见相关代码:

- `pyportable_installer/venv_builder.py: class VEnvBuilder`
- `pyportable_installer/assets_copy.py: def copy_venv`
- `pyportable_installer/no3_build_pyproject.py: def main`
